#ifdef QT_PLATFORM

#include "monkey_face.h"
#include "../res/app/app_res.h"
#include "../res/os/os_res.h"
#include "../os_kernel/os_printk.h"
#include "../os_kernel/os_timer.h"
#include "../maibu_sdk/maibu_sdk.h"
#include "../res/app/app_res.h"
#include "watchapp_health_manager.h"
#include "../os_kernel/os_printk.h"
#include "lunar_algorithm.h"

#define  LOG_INFO  os_printk

#else

#include "maibu_sdk.h"
#include "maibu_res.h"
#include "lunar_algorithm.h"

#define  LOG_INFO(...)

#endif

#define MONKEY_KEY                 1

#define UTF8_CN_CODE_LEN           3

#define TIME_TEXT_POS_X            0
#define TIME_TEXT_POS_Y            30
#define TIME_TEXT_SIZE_H           30
#define TIME_TEXT_SIZE_W           128

#define DATE_TEXT_POS_X            0
#define DATE_TEXT_POS_Y            60
#define DATE_TEXT_SIZE_H           12
#define DATE_TEXT_SIZE_W           128

#define LUNAR_DATE_TEXT_POS_X      0
#define LUNAR_DATE_TEXT_POS_Y      77
#define LUNAR_DATE_TEXT_SIZE_H     12
#define LUNAR_DATE_TEXT_SIZE_W     128

static char weekday[7][11] =
{
    {" 周天"},
    {" 周一"},
    {" 周二"},
    {" 周三"},
    {" 周四"},
    {" 周五"},
    {" 周六"}
};

static int32_t g_time_text_id       = -1;
static int32_t g_date_text_id       = -1;
static int32_t g_lunar_date_text_id = -1;
static int32_t g_window_id          = -1;
static uint32_t g_comm_id_web;

static int32_t g_monkey_timer_id    = -1;

static P_Window monkey_face_window_init(void);

static void watch_time_change(enum SysEventType type, void *context)
{
    char text_buf[40];
    GRect frame;

    P_Window p_window = app_window_stack_get_window_by_id(g_window_id);
    if (p_window == NULL)
    {
        return;
    }

    /*时间更改，分变化*/
    if (type == SysEventTypeTimeChange)
    {
        struct date_time t;
        app_service_get_datetime(&t);

        //更新公立时间
        //添加时间栏, 文本图层
        memset(text_buf, 0, sizeof(text_buf));
        sprintf(text_buf, "%02d:%02d", t.hour, t.min);

        frame.origin.x = TIME_TEXT_POS_X;
        frame.origin.y = TIME_TEXT_POS_Y;
        frame.size.h   = TIME_TEXT_SIZE_H;
        frame.size.w   = TIME_TEXT_SIZE_W;

        LayerText time_text  = {(const char*)text_buf, frame, GAlignCenter, U_ASCII_ARIAL_30, 0};
        P_Layer   new_time_layer = app_layer_create_text(&time_text);
        P_Layer   old_time_layer = app_window_get_layer_by_id(p_window, g_time_text_id);

        if(old_time_layer)
        {
            g_time_text_id = app_window_replace_layer(p_window, old_time_layer, new_time_layer);
        }

        //添加公历月日、星期X 文本图层
        memset(text_buf, 0, sizeof(text_buf));

        sprintf((char *)text_buf, "%d月%d日", t.mon, t.mday);
        my_strcat((char *)text_buf, (char *)&weekday[t.wday][0]);

        frame.origin.x = DATE_TEXT_POS_X;
        frame.origin.y = DATE_TEXT_POS_Y;
        frame.size.h   = DATE_TEXT_SIZE_H;
        frame.size.w   = DATE_TEXT_SIZE_W;

        LayerText date_text  = {(const char*)text_buf, frame, GAlignCenter, U_ASCII_ARIAL_12, 0};
        P_Layer   new_date_layer = app_layer_create_text(&date_text);
        P_Layer   old_date_layer = app_window_get_layer_by_id(p_window, g_date_text_id);

        if(old_date_layer)
        {
            g_date_text_id = app_window_replace_layer(p_window, old_date_layer, new_date_layer);
        }

        //更新阴历时间
        memset(text_buf, 0, sizeof(text_buf));
        get_lunar_date_str(t.year, t.mon, t.mday, text_buf);

        frame.origin.x = LUNAR_DATE_TEXT_POS_X;
        frame.origin.y = LUNAR_DATE_TEXT_POS_Y;
        frame.size.h   = LUNAR_DATE_TEXT_SIZE_H;
        frame.size.w   = LUNAR_DATE_TEXT_SIZE_W;

        LayerText lunar_date_text  = {(const char*)text_buf, frame, GAlignCenter, U_ASCII_ARIAL_12, 0};
        P_Layer   lunar_date_layer = app_layer_create_text(&lunar_date_text);
        app_layer_set_bg_color(lunar_date_layer, GColorBlack);

        P_Layer old_lunar_date_layer = app_window_get_layer_by_id(p_window, g_lunar_date_text_id);

        if(old_lunar_date_layer)
        {
            g_lunar_date_text_id = app_window_replace_layer(p_window, old_lunar_date_layer, lunar_date_layer);
        }

        app_window_update(p_window);
    }
}


static P_Window monkey_face_window_init(void)
{
    /*创建窗口*/
    P_Window p_window = app_window_create();
    if (NULL == p_window)
    {
        return p_window;
    }

    uint8_t text_buf[40]= {0};
    struct date_time t;
    app_service_get_datetime(&t);

    //添加表盘背景
    GRect frame = {{0, 0}, {128, 128}};
    GBitmap bitmap;
    res_get_user_bitmap(BMP_MONKEY_FACE_BG, &bitmap);
    LayerBitmap layer_bitmap = {bitmap, frame, GAlignCenter};
    P_Layer bitmap_layer = app_layer_create_bitmap(&layer_bitmap);

    app_window_add_layer(p_window, bitmap_layer);

    //添加时间栏, 文本图层
    memset(text_buf, 0, sizeof(text_buf));
    sprintf(text_buf, "%02d:%02d", t.hour, t.min);

    frame.origin.x = TIME_TEXT_POS_X;
    frame.origin.y = TIME_TEXT_POS_Y;
    frame.size.h   = TIME_TEXT_SIZE_H;
    frame.size.w   = TIME_TEXT_SIZE_W;

    LayerText time_text  = {(const char*)text_buf, frame, GAlignCenter, U_ASCII_ARIAL_30, 0};
    P_Layer   time_layer = app_layer_create_text(&time_text);
    g_time_text_id       = app_window_add_layer(p_window, time_layer);

    //添加公历月日、星期X 文本图层
    memset(text_buf, 0, sizeof(text_buf));

    sprintf((char *)text_buf, "%d月%d日", t.mon, t.mday);
    my_strcat((char *)text_buf, (char *)&weekday[t.wday][0]);

    frame.origin.x = DATE_TEXT_POS_X;
    frame.origin.y = DATE_TEXT_POS_Y;
    frame.size.h   = DATE_TEXT_SIZE_H;
    frame.size.w   = DATE_TEXT_SIZE_W;

    LayerText date_text  = {(const char*)text_buf, frame, GAlignCenter, U_ASCII_ARIAL_12, 0};
    P_Layer   date_layer = app_layer_create_text(&date_text);
    g_date_text_id       = app_window_add_layer(p_window, date_layer);

    //更新阴历时间
    memset(text_buf, 0, sizeof(text_buf));
    get_lunar_date_str(t.year, t.mon, t.mday, text_buf);

    frame.origin.x = LUNAR_DATE_TEXT_POS_X;
    frame.origin.y = LUNAR_DATE_TEXT_POS_Y;
    frame.size.h   = LUNAR_DATE_TEXT_SIZE_H;
    frame.size.w   = LUNAR_DATE_TEXT_SIZE_W;

    LayerText lunar_date_text  = {(const char*)text_buf, frame, GAlignCenter, U_ASCII_ARIAL_12, 0};
    P_Layer   lunar_date_layer = app_layer_create_text(&lunar_date_text);
    app_layer_set_bg_color(lunar_date_layer, GColorBlack);
    g_lunar_date_text_id       = app_window_add_layer(p_window, lunar_date_layer);

    return p_window;
}

int monkey_face_init(void)
{
    P_Window p_window;
    struct date_time t;
    app_service_get_datetime(&t);

    /*注册一个事件通知回调，当有时间改变是，立即更新时间*/
    maibu_service_sys_event_subscribe(watch_time_change);

    /* 初始化窗口并获取一次农历数据 */
    p_window = monkey_face_window_init();

    /*把窗口放入窗口栈中显示*/
    g_window_id = app_window_stack_push(p_window);

    return 0;
}


#ifndef QT_PLATFORM

int main(void)
{
    monkey_face_init();
}

#endif






